@@ -3,7 +3,7 @@ package Task::BeLike::JMATES::WorkWorkWork;
 use 5.010000;
 use strict;
 use warnings;
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 1;
 __END__
@@ -24,11 +24,13 @@ Task::BeLike::JMATES::WorkWorkWork - modules used by JMATES (for work)
   # bring in a modern version of Perl due to $VENDOR at $WORK using a
   # version of perl last seen frolicking in the late Devonian
   unset PERL5LIB PERL_LOCAL_LIB_ROOT PERL_MB_OPT PERL_MM_OPT
-  cd perl-5.16.3
-  ./Configure -des -Dprefix=$HOME/usr/perl-5.16.3
+  cd perl-5.22.0
+  ./Configure -des -Dprefix=$HOME/usr/$OSTYPE-$MACHTYPE/perl-5.22.0
   make test
   make install
   $HOME/usr/perl-5.16.3/bin/cpan Task::BeLike::JMATES::WorkWorkWork
+  # (or instead install Perl::Build and then use `perl-build ...`
+  # to install a custom version of perl.)
 
 =head1 DESCRIPTION
 
